// ========================================================================================
//	TTextDocument.h			 	Copyright (C) 2001-2002 Mike Lockwood. All rights reserved.
// ========================================================================================
/*
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef __TTextDocument__
#define __TTextDocument__

#include "fw/TDocument.h"

class TTextView;
class TDocumentWindow;
class TMenuBar;
class TWindow;
class TFunctionsMenu;


class TTextDocument : public TDocument
{
public:
	static TDocument*	CreateDocument(TFile* file);

	inline TTextView*	GetTextView() const { return fTextView; }

protected:
						TTextDocument(TFile* file);
	virtual				~TTextDocument();

	virtual void		Open(TDocumentWindow* window);

	virtual void		ReadFromFile(TFile* file);
	virtual void		WriteToFile(TFile* file);

	virtual void		SetTitle(const TChar* title);

protected:
	TMenuBar*			MakeMenuBar(TWindow* window);
	virtual bool		DoCommand(TCommandHandler* sender, TCommandHandler* receiver, TCommandID command);
	virtual bool		DoKeyDown(KeySym key, TModifierState state, const char* string);
	
	void				AddFunctionsMenu();
	void				RemoveFunctionsMenu();

	void				AddHTMLMenu();
	void				RemoveHTMLMenu();

protected:
	TTextView*			fTextView;
	TFunctionsMenu*		fFunctionsMenu;
	TMenu*				fHTMLMenu;
	TMenu*				fWindowsMenu;
	TMenuBar*			fMenuBar;
};


#endif // __TTextDocument__
